# Table of Contents

- [modeling-sap-erp-60](<./modeling-sap-erp-60.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling SAP ERP 6.0](<./Modeling-SAP-ERP-6.0.md>)
  - [Overview](<./Modeling-SAP-ERP-6.0/Overview.md>)
  - [General Guidelines for Modeling SAP ERP 6.0](<./Modeling-SAP-ERP-6.0/General-Guidelines-for-Modeling-SAP-ERP-6.0.md>)
  - [Modeling SAP Product Versions, Software Components, Technical Components, and Interfaces](<./Modeling-SAP-ERP-6.0/Modeling-SAP-Product-Versions-Software-Components-Technical-Components-and-Interfaces.md>)
  - [Modeling Instances of Systems](<./Modeling-SAP-ERP-6.0/Modeling-Instances-of-Systems.md>)
